#
# spec file for package kuberlr
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           kuberlr
Version:        0.5.2
Release:        1.1
Summary:        A tool that simplifies the management of multiple versions of kubectl
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/flavio/kuberlr
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) = 1.23
Requires(post): %fillup_prereq
Requires(post): update-alternatives
Requires(postun): update-alternatives
%if 0%{?suse_version} <= 1500
Conflicts:      kubernetes-client
%endif
Provides:       kubernetes-client-provider = %{version}

%description
kuberlr (kube-ruler) is a simple wrapper for kubectl. Its main purpose is to
make it easy to manage clusters running different versions of kubernetes.

%prep
%setup -q -a1
%setup -q -T -D -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X=github.com/flavio/kuberlr/pkg/kuberlr.Version=%{version}" \
   -o %{name} ./cmd/%{name}

%install
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"
%if 0%{?suse_version} <= 1500
install -D -m 0644 %{name}.conf.example %{buildroot}/%{_sysconfdir}/%{name}.conf
%else
install -D -m 0644 %{name}.conf.example %{buildroot}/%{_distconfdir}/%{name}.conf
%endif
# update alternatives
ln -s %{_sysconfdir}/alternatives/kubectl %{buildroot}%{_bindir}/kubectl

%post
%{_sbindir}/update-alternatives \
  --install %{_bindir}/kubectl kubectl %{_bindir}/kuberlr 1000

%postun
if [ ! -f %{_bindir}/%{name} ] ; then
  update-alternatives --remove kubectl %{_bindir}/%{name}
fi

%files
%license LICENSE
%doc README.md
%{_bindir}/kubectl
%{_bindir}/%{name}
%ghost %{_sysconfdir}/alternatives/kubectl
%if 0%{?suse_version} <= 1500
%config %{_sysconfdir}/%{name}.conf
%else
%{_distconfdir}/%{name}.conf
%endif

%changelog
* Fri Jan 31 2025 Earl Sampson <esampson@suse.com>
- BuildRequire go 1.22.3 or higher
* Fri Jan 31 2025 esampson@suse.com
- Update to version 0.5.2:
  * automation: switch to release-drafter
  * refactor: small improvements to tests
  * test: update to latest version of golangci
  * refactor: improve tests
  * chore(deps): Bump actions/attest-build-provenance from 1.4.1 to 1.4.2
  * Fix typo and add tests
  * Small refactoring
  * Fix infinite recursion loop with kube login
  * chore(deps): Bump docker/build-push-action from 6.6.1 to 6.7.0
  * chore(deps): Bump k8s.io/client-go from 0.30.3 to 0.31.0
  * chore(deps): Bump actions/attest-build-provenance from 1.4.0 to 1.4.1
  * chore(deps): Bump sigstore/cosign-installer from 3.5.0 to 3.6.0
  * chore(deps): Bump docker/build-push-action from 5.3.0 to 6.6.1
  * automation: fix release action
  * Tag all actions by sha
  * Remove goreleaser config comments
  * Make machine name more generic
  * seed bash completion at build time
  * add attestation settings and step
  * Add kuberlr completion
  * Update release to publish docker image too
  * Add dockerfile with local make script
  * update goreleaser config with version
  * chore(deps): Bump github.com/schollz/progressbar/v3
  * chore(deps): Bump github.com/schollz/progressbar/v3
  * chore(deps): Bump k8s.io/client-go from 0.30.2 to 0.30.3
  * chore(deps): Bump github.com/spf13/cobra from 1.8.0 to 1.8.1
  * chore(deps): Bump k8s.io/client-go from 0.30.1 to 0.30.2
  * chore(deps): Bump github.com/schollz/progressbar/v3
  * chore(deps): Bump goreleaser/goreleaser-action from 5.1.0 to 6.0.0
  * chore(deps): Bump github.com/spf13/viper from 1.18.2 to 1.19.0
  * chore(deps): update go, golangci, gorelease
  * chore(deps): run go mod tidy
  * --- updated-dependencies: - dependency-name: github.com/schollz/progressbar/v3   dependency-type: direct:production   update-type: version-update:semver-patch ...
  * build(deps): bump k8s.io/client-go from 0.29.3 to 0.30.1
  * build(deps): bump goreleaser/goreleaser-action from 5.0.0 to 5.1.0
  * build(deps): bump golangci/golangci-lint-action from 4 to 6
  * build(deps): bump github.com/jedib0t/go-pretty/v6 from 6.5.6 to 6.5.9
  * build(deps): bump golang.org/x/net from 0.19.0 to 0.23.0
  * refactor: cleanup checksum code
  * skip gosec in linting, verify old binaries with sha1
  * fix lint
  * fix typo
  * add types for download args
  * update shaURLToGet
  * fix typo
  * use sha512 checksum for ver>=1.12, and sha1 for old versions
  * Update README
  * set DisableFlagParsing to true for NewKubectlWrapperCmd
  * format code
  * DisableFlagParsing for NewKubectlWrapperCmd
  * remove unused lint directive
  * add kubectl subcommand
  * Small fixes to Kubernetes mirror patch
  * build(deps): bump github.com/jedib0t/go-pretty/v6 from 6.5.5 to 6.5.6
  * remove unused lint directive
  * fix getKbReleaseURL
  * add config key KbReleaseUrl for custom download mirror
  * build(deps): bump k8s.io/client-go from 0.29.2 to 0.29.3
  * build(deps): bump github.com/jedib0t/go-pretty/v6 from 6.5.4 to 6.5.5
  * build(deps): bump google.golang.org/protobuf from 1.31.0 to 1.33.0
  * build(deps): bump github.com/schollz/progressbar/v3
  * build(deps): bump k8s.io/client-go from 0.29.1 to 0.29.2
  * build(deps): bump golangci/golangci-lint-action from 3 to 4
  * build(deps): bump github.com/jedib0t/go-pretty/v6 from 6.5.3 to 6.5.4
  * build(deps): bump k8s.io/client-go from 0.29.0 to 0.29.1
  * build(deps): bump github.com/jedib0t/go-pretty/v6 from 6.5.2 to 6.5.3
  * build(deps): bump github.com/jedib0t/go-pretty/v6 from 6.5.1 to 6.5.2
  * build(deps): bump github.com/jedib0t/go-pretty/v6 from 6.4.9 to 6.5.1
  * Use context passed via the commandline when discovering cluster version
  * build(deps): bump github.com/spf13/viper from 1.18.1 to 1.18.2
  * build(deps): bump github.com/spf13/viper from 1.16.0 to 1.18.1
  * chore(deps): update to latest version of golangci
  * build(deps): bump k8s.io/client-go from 0.28.4 to 0.29.0
  * build(deps): bump actions/setup-go from 4 to 5
  * build(deps): bump k8s.io/client-go from 0.28.3 to 0.28.4
  * build(deps): bump github.com/spf13/cobra from 1.7.0 to 1.8.0
  * build(deps): bump github.com/schollz/progressbar/v3
  * build(deps): bump github.com/schollz/progressbar/v3
  * build(deps): bump github.com/jedib0t/go-pretty/v6 from 6.4.8 to 6.4.9
  * build(deps): bump k8s.io/client-go from 0.28.2 to 0.28.3
  * build(deps): bump golang.org/x/net from 0.13.0 to 0.17.0
  * build(deps): bump github.com/jedib0t/go-pretty/v6 from 6.4.7 to 6.4.8
  * build(deps): bump k8s.io/client-go from 0.28.1 to 0.28.2
  * fix: support global kubectl options
  * Remove changelog file
  * fix: goreleaser grant the right privileges
  * automation: fix goreleaser config
  * automation: remove release-drafter
  * automation: enable cosign
  * chore(deps): update k8s.io/client
  * test: fix broken GH action
  * test: refactor GH action
  * test: update go version used by GH actions
  * test: fix linter warnings
  * test: switch to golangci
  * chore(deps): bump go version
  * chore: cleanup Makefile
  * Bump github.com/schollz/progressbar/v3 from 3.3.1 to 3.13.1
  * Bump github.com/spf13/viper from 1.4.0 to 1.16.0
  * Bump github.com/spf13/cobra from 1.0.0 to 1.7.0
  * Bump github.com/jedib0t/go-pretty/v6 from 6.0.4 to 6.4.7
  * Bump actions/setup-go from 2 to 4
  * Bump actions/checkout from 2 to 4
  * chore(automation): configure dependabot
  * chore: update release actions
  * fix: release-drafter enable master branch
  * chore: add release-drafter
  * Added the s390x architecture
  * Bump golang.org/x/net from 0.0.0-20220722155237-a158d28d115b to 0.7.0
  * Bump k8s.io/client-go from 0.17.0 to 0.20.0
  * Enable building universal binaries for macos
  * Fix go vet
  * Fix go fmt errors
  * GitHub Action test workflow: update go version
  * Fixes the command output when the Kubernetes server is unreachable.
  * Fix BiDi rendering issue for asterisk
  * Downloader: don't shadow err
  * Switch go version from 1.13 to 1.17 to support darwin/arm64 builds
* Fri Jan  7 2022 kastl@b1-systems.de
- Update to version 0.4.1:
  * Tag release 0.4.1
  * Fixing issue of process holding on to file during rename
* Fri Jan  7 2022 kastl@b1-systems.de
- Update to version 0.4.0:
  * Release version 0.4.0
  * Fix error reporting inside of downloader
  * Add `get` command
  * Update github.com/blang/semver dependency
  * Don't parse kubectl commandline with flag.Parse()
* Fri Jan  7 2022 kastl@b1-systems.de
- Update to version 0.3.2:
  * Tag version v0.3.2
  * Act on linter directives
  * Copy the temp file to dest only if rename fails
  * style improvements - no functional change
  * download the hash before the document
  * ioutil.TempFile returns an open file object
  * Convert the sha mismatch error msg into a custom error
  * When downloading versions of kubectl, verify their contents against known SHA256 hashes
  * Remove vendored tree
  * Allow to override build date with SOURCE_DATE_EPOCH
* Fri Jan  7 2022 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire go 1.16 or higher
- major overhaul of the package to adhere to common go build commands
  - use 'buildmode=pie'
  - strip binary
  - do not use the Makefile, instead directly run the few commands
* Fri Sep 11 2020 dmueller@suse.com
- Update to version 0.3.1:
  * Prepare for release of v0.3.1
  * fix: set progress bar desc to shorter string
  * Update Changelog
  * Update README to mention all the platforms supported
  * GitHub actions: enable test matrix
  * Build kuberlr binary for windows
  * windows: fix path construction for download dir
  * windows: require .exe extension on windows
  * windows: add filename extension utils
* Tue Jul 14 2020 Dirk Mueller <dmueller@suse.com>
- fix update-alternatives logic
- set highest priority
* Mon Jul 13 2020 Dirk Mueller <dmueller@suse.com>
- spec file cleanups
- use vendor.tar.gz
* Fri Jul 10 2020 Flavio Castelli <fcastelli@suse.com>
- Update to version 0.3.0
- Ensure OIDC authentication works
* Mon Jul  6 2020 Flavio Castelli <fcastelli@suse.com>
- Ensure the right version of Go is used, this fixes builds on
  tumbleweed
* Mon Jul  6 2020 Flavio Castelli <fcastelli@suse.com>
- Update to version version 0.2.1
